Affected by GO-2024-2996
and 20 other vulnerabilities
GO-2024-2996: CVE-2024-21527 in github.com/gotenberg/gotenberg
GO-2026-4905: Gotenberg has Chromium deny-list bypass via case-insensitive URL scheme (bypass of GHSA-rh2x-ccvw-q7r3) in github.com/gotenberg/gotenberg
GO-2026-4990: Gotenberg's DNS rebinding bypasses SSRF validation on Chromium URL conversion routes in github.com/gotenberg/gotenberg
GO-2026-5060: Gotenberg: SSRF via LibreOffice document processing in github.com/gotenberg/gotenberg
GO-2026-5080: Gotenberg has arbitrary PDF read via stampExpression and watermarkExpression in merge, split, and convert routes in github.com/gotenberg/gotenberg
GO-2026-5132: Gotenberg vulnerable to unauthenticated SSRF via default deny-list bypass in downloadFrom and webhook in github.com/gotenberg/gotenberg
GO-2026-5151: Gotenberg has case-insensitive URL scheme that bypasses webhook and downloadFrom deny-list SSRF protection in github.com/gotenberg/gotenberg
GO-2026-5155: Gotenberg Vulnerable to Unauthenticated SSRF via Unfiltered Webhook URL in github.com/gotenberg/gotenberg
GO-2026-5162: Gotenberg has an ExifTool Dangerous Tag Blocklist Bypass via Group-Prefixed Tag Names that Allows Arbitrary File Rename and Move in github.com/gotenberg/gotenberg
GO-2026-5234: Gotenberg's ExifTool group-prefix syntax bypasses dangerous-tag blocklist in github.com/gotenberg/gotenberg
GO-2026-5244: Gotenberg has an SSRF deny-list bypass in IsPublicIP via IPv6 6to4 / NAT64 / site-local prefixes in github.com/gotenberg/gotenberg
GO-2026-5324: Gotenberg: Server-Side Request Forgery via Chromium URL Endpoint with Redirect-Based Deny-List Bypass in github.com/gotenberg/gotenberg
GO-2026-5372: Gotenberg Vulnerable to ReDoS via extraHttpHeaders scope feature in github.com/gotenberg/gotenberg
GO-2026-5395: Gotenberg allows Chromium URL conversion routes to read arbitrary files under /tmp via file:// scheme in github.com/gotenberg/gotenberg
GO-2026-5443: Gotenberg has path traversal in zip entry name via Windows-style separators in upload filename in github.com/gotenberg/gotenberg
GO-2026-5572: Gotenberg has ExifTool stdin argument injection via metadata value newlines (bypass of key sanitization fix) in github.com/gotenberg/gotenberg
GO-2026-5587: Gotenberg has incomplete fix for ExifTool arbitrary file write: case-insensitive bypass and missing HardLink/SymLink tags in github.com/gotenberg/gotenberg
GO-2026-5605: Gotenberg has an unauthenticated denial of service via echo.Context pool reuse in webhook async goroutine in github.com/gotenberg/gotenberg
GO-2026-5627: Gotenberg has a Server-Side Request Forgery (SSRF) Issue in github.com/gotenberg/gotenberg
GO-2026-5636: Gotenberg has Unauthenticated RCE via ExifTool Metadata Key Injection in github.com/gotenberg/gotenberg
GO-2026-5669: Gotenberg has a Race Condition via Multipart `downloadFrom` Handling in github.com/gotenberg/gotenberg
type PDFEngines struct {
// contains filtered or unexported fields
}
PDFEngines is a module which gathers available gotenberg.PDFEngine modules.
The available gotenberg.PDFEngine modules can be either all
gotenberg.PDFEngine modules or the modules selected by the user thanks to
the "engines" flag.
PDFEngines wraps the gotenberg.PDFEngine modules in an internal struct which
also implements gotenberg.PDFEngine. This struct provides a sort of fallback
mechanism: if an engine's method returns an error, it calls the same method
from another engine.
This module implements the gotenberg.PDFEngineProvider interface.
Validate validates there is at least one gotenberg.PDFEngine module
available. It also validates that selected gotenberg.PDFEngine modules
actually exist.