webhook

package
v8.30.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 6, 2026 License: MIT Imports: 25 Imported by: 0

Documentation

Overview

Package webhook adds middleware for uploading output files to any destination asynchronously.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Webhook

type Webhook struct {
	// contains filtered or unexported fields
}

Webhook is a module that provides a middleware for uploading output files to any destinations in an asynchronous fashion.

func (*Webhook) AsyncCount added in v8.21.0

func (w *Webhook) AsyncCount() int64

AsyncCount returns the number of asynchronous requests.

func (*Webhook) Descriptor

func (w *Webhook) Descriptor() gotenberg.ModuleDescriptor

Descriptor returns an Webhook's module descriptor.

func (*Webhook) Middlewares

func (w *Webhook) Middlewares() ([]api.Middleware, error)

Middlewares returns the middleware.

func (*Webhook) Provision

func (w *Webhook) Provision(ctx *gotenberg.Context) error

Provision sets the module properties.

Jump to